@@ -16,12 +16,13 @@ ar_wkt <- "POLYGON ((0 0, 10 0, 10 10, 0 10, 0 0), (1 1, 1 8, 3 8, 3 1, 1 1), (3
 irir_wkt <- "POLYGON ((0 0, 10 0, 10 10, 0 10, 0 0), (2 8, 5 8, 5 2, 2 2, 2 8), (3 3, 4 3, 3 4, 3 3))"
 library(sf)
 from_wkt <- function(x) st_as_sf(data.frame(geometry = x), wkt = "geometry")
-is_valid_wkt <- function(x) st_is_valid(from_wkt(x))
+is_valid_wkt <- function(x) st_is_valid(from_wkt(x), reason = TRUE)
 fix_wkt <- function(x) st_union(ct_triangulate(from_wkt(x)), by_feature = TRUE)
 test_that("bowtie is fixed", {
   wkt <- bt_wkt
-  expect_warning(the_test <- is_valid_wkt(wkt), "Self-intersection")
-  expect_false(the_test)
+  thetest <- is_valid_wkt(wkt)
+  expect_match(thetest, "Self-intersection")
+  expect_false(isTRUE(thetest))
   expect_true(st_is_valid(fix_wkt(wkt)))
 })
 
@@ -30,7 +31,7 @@ test_that("Square with wrong orientation", {
   context("st_is_valid does not care about orientation")
   ##expect_warning(the_test <- is_valid_wkt(wkt), "Self-intersection")
   the_test <- is_valid_wkt(wkt)
-  expect_true(the_test)
+  expect_match(the_test, "Valid Geometry")
 
   context("the fix is ok")
   expect_true(st_is_valid(fix_wkt(wkt)))
@@ -42,15 +43,15 @@ test_that("Square with wrong orientation", {
 
 test_that("Inner ring with one edge sharing part of an edge of the outer ring:", {
   wkt <- ir_or_wkt
-  expect_warning(the_test <- is_valid_wkt(wkt), "Self-intersection")
-  expect_false(the_test)
+  expect_match(the_test <- is_valid_wkt(wkt), "Self-intersection")
+  expect_false(isTRUE(the_test))
   expect_true(st_is_valid(fix_wkt(wkt)))
 })
 
 test_that("Dangling edge", {
   wkt <- de_wkt
-  expect_warning(the_test <- is_valid_wkt(wkt), "Self-intersection")
-  expect_false(the_test)
+  expect_match(the_test <- is_valid_wkt(wkt), "Self-intersection")
+  expect_false(isTRUE(the_test))
   expect_true(st_is_valid(fix_wkt(wkt)))
 })
 #
@@ -64,14 +65,14 @@ test_that("Dangling edge", {
 
 test_that("#Two adjacent inner rings:", {
   wkt <- ar_wkt
-  expect_warning(the_test <- is_valid_wkt(wkt), "Self-intersection")
-  expect_false(the_test)
+  expect_match(the_test <- is_valid_wkt(wkt), "Self-intersection")
+  expect_false(isTRUE(the_test))
   expect_true(st_is_valid(fix_wkt(wkt)))
 })
 
 test_that("Polygon with an inner ring inside another inner ring", {
   wkt <- irir_wkt
-  expect_warning(the_test <- is_valid_wkt(wkt), "Holes are nested at or near point 3 3")
-  expect_false(the_test)
+  expect_match(the_test <- is_valid_wkt(wkt), "Holes are nested\\[3 3\\]")
+  expect_false(isTRUE(the_test))
   expect_true(st_is_valid(fix_wkt(wkt)))
 })
